==> qtjambi-xml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiXml/QDomComment_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomComment(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomComment")
    QDomComment *_ptr = reinterpret_cast<QDomComment *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomComment()
void __qt_construct_QDomComment_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomComment()")
    Q_UNUSED(__java_arguments)
    QDomComment *__qt_this = new(__qtjambi_ptr) QDomComment();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDomComment(QDomComment)
void __qt_construct_QDomComment_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomComment(QDomComment)")
    jobject x0 = __java_arguments[0].l;
    const QDomComment& __qt_x0 = qtjambi_cast<const QDomComment& >(__jni_env, x0);
    QDomComment *__qt_this = new(__qtjambi_ptr) QDomComment(__qt_x0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDomComment
void __qt_destruct_QDomComment(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomComment")
    reinterpret_cast<QDomComment*>(ptr)->~QDomComment();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomComment::QDomComment()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_initialize_1native__Lio_qt_xml_QDomComment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomComment::QDomComment()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomComment_0, sizeof(QDomComment), typeid(QDomComment), false, &deleter_QDomComment, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomComment::QDomComment(QDomComment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_initialize_1native__Lio_qt_xml_QDomComment_2Lio_qt_xml_QDomComment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomComment::QDomComment(QDomComment)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomComment_1, sizeof(QDomComment), typeid(QDomComment), false, &deleter_QDomComment, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomComment::operator=(QDomComment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_assign_1native_1cref_1QDomComment__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomComment *__qt_this = QtJambiAPI::objectFromNativeId<QDomComment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomComment::operator=(QDomComment)", __qt_this)
        const QDomComment& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomComment>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomComment *__qt_this = QtJambiAPI::objectFromNativeId<QDomComment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomComment(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomComment>("QDomComment", "io/qt/xml/QDomComment");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomComment, {
        ConstructorInfo(&__qt_construct_QDomComment_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomComment_1, "Lio/qt/xml/QDomComment;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomComment);
    registerMetaType<QDomComment>("QDomComment");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiXml/QDomComment_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomComment(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomComment")
    QDomComment *_ptr = reinterpret_cast<QDomComment *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomComment()
void __qt_construct_QDomComment(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomComment()")
    Q_UNUSED(__java_arguments)
    QDomComment *__qt_this = new(__qtjambi_ptr) QDomComment();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDomComment::QDomComment()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_initialize_1native__Lio_qt_xml_QDomComment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomComment::QDomComment()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomComment, sizeof(QDomComment), typeid(QDomComment), false, &deleter_QDomComment, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomComment(QDomComment)
void __qt_construct_QDomComment_cref_QDomComment(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomComment(QDomComment)")
    jobject x0 = __java_arguments[0].l;
    const QDomComment& __qt_x0 = qtjambi_cast<const QDomComment& >(__jni_env, x0);
    QDomComment *__qt_this = new(__qtjambi_ptr) QDomComment(__qt_x0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDomComment::QDomComment(QDomComment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_initialize_1native__Lio_qt_xml_QDomComment_2Lio_qt_xml_QDomComment_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomComment::QDomComment(QDomComment)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomComment_cref_QDomComment, sizeof(QDomComment), typeid(QDomComment), false, &deleter_QDomComment, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomComment
void __qt_destruct_QDomComment(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomComment")
    reinterpret_cast<QDomComment*>(ptr)->~QDomComment();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomComment::operator=(QDomComment)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_assign_1native_1cref_1QDomComment__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomComment *__qt_this = QtJambiAPI::objectFromNativeId<QDomComment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomComment::operator=(QDomComment)", __qt_this)
        const QDomComment& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomComment>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomComment_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomComment *__qt_this = QtJambiAPI::objectFromNativeId<QDomComment>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomComment(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomComment>("QDomComment", "io/qt/xml/QDomComment");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomComment, {
        ConstructorInfo(&__qt_construct_QDomComment, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomComment_cref_QDomComment, "Lio/qt/xml/QDomComment;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomComment);
    registerMetaType<QDomComment>("QDomComment");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
